@@ -6,6 +6,8 @@ VIDEO_FORMAT = (".mp4", ".m4v", ".mov", ".avi", ".wmv", ".flv", ".qt", ".asf", "
 class FPS(object):
     def __init__(self):
         self.frame = 0
+        self.start_time = 0
+        self.elapsed_time = 0
         
     def start(self):
         self.start_time = time.time()
